%{
/*-
 * Copyright (c) 2008, Florent Thoumie <flz@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD$
 */

#include <stdlib.h>
#include <string.h>
#include <err.h>

#include "lib.h"
#include "config.h"

#define	YY_NO_UNPUT

int	yylex(void);
void	yyerror(const char *);

int lineno = 1;
char configfile[FILENAME_MAX];

%}

%option noyywrap

%%

#.*			;
[ \t]+			;
\n			{ lineno++; }
\{			{ return OBRACE; }
\}			{ return CBRACE; }
,			{ return COMMA; }
=			{ return EQ; }
[a-zA-Z0-9.:/_-]+	{
			  yylval.str = strdup(yytext);
			  if (yylval.str == NULL)
			  	err(1, "strdup");
			  return STRING;
			}

%%

void
yyerror(const char *s)
{

	printf("%s: line %d: %s: %s\n", configfile, lineno, s, yytext);
	exit(1);
}
